==> wawa-service-api-0.0.5-20171028.051825-1-sources.jar: cn/com/wawa/service/api/dto/WawaCatcherSaveDto.java <==
package cn.com.wawa.service.api.dto;

import java.io.Serializable;

/**
 * Created by gyf .
 * 2017/10/27 .
 */
public class WawaCatcherSaveDto implements Serializable {

    private static final long serialVersionUID = 2565785986728537637L;

    /**
     * 娃娃机id
     */
    private Long id;

    /**
     * 娃娃机编号
     */
    private Integer catcherNum;

    /**
     * 娃娃机名称
     */
    private String catcherName;

    /**
     * mac1
     */
    private String mac1;

    /**
     * mac2
     */
    private String mac2;

    /**
     * 娃娃机排序值
     */
    private Long payload;

    /**
     * 娃娃id
     */
    private Long wawaId;

    /**
     * 娃娃总数
     */
    private Integer totality;

    /**
     * 娃娃剩余数量
     */
    private Integer stock;

    public String getMac1() {
        return mac1;
    }

    public void setMac1(String mac1) {
        this.mac1 = mac1;
    }

    public String getMac2() {
        return mac2;
    }

    public void setMac2(String mac2) {
        this.mac2 = mac2;
    }

    public Integer getCatcherNum() {
        return catcherNum;
    }

    public void setCatcherNum(Integer catcherNum) {
        this.catcherNum = catcherNum;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getCatcherName() {
        return catcherName;
    }

    public void setCatcherName(String catcherName) {
        this.catcherName = catcherName;
    }

    public Long getPayload() {
        return payload;
    }

    public void setPayload(Long payload) {
        this.payload = payload;
    }

    public Long getWawaId() {
        return wawaId;
    }

    public void setWawaId(Long wawaId) {
        this.wawaId = wawaId;
    }

    public Integer getTotality() {
        return totality;
    }

    public void setTotality(Integer totality) {
        this.totality = totality;
    }

    public Integer getStock() {
        return stock;
    }

    public void setStock(Integer stock) {
        this.stock = stock;
    }
}

==> wawa-service-api-0.0.14-20171201.121618-1-sources.jar: cn/com/wawa/service/api/dto/WawaCatcherSaveDto.java <==
package cn.com.wawa.service.api.dto;

import java.io.Serializable;

/**
 * Created by gyf . 2017/10/27 .
 */
public class WawaCatcherSaveDto implements Serializable {

    private static final long serialVersionUID = 2565785986728537637L;

    /**
     * 娃娃机id
     */
    private Long              id;

    /**
     * 娃娃机编号
     */
    private Integer           catcherNum;

    /**
     * 娃娃机名称
     */
    private String            catcherName;

    /**
     * mac1
     */
    private String            mac1;

    /**
     * mac2
     */
    private String            mac2;

    /**
     * 娃娃机排序值
     */
    private Long              payload;

    /**
     * 娃娃id
     */
    private Long              wawaId;

    /**
     * 娃娃总数
     */
    private Integer           totality;

    /**
     * 娃娃剩余数量
     */
    private Integer           stock;

    /**
     * 娃娃机版本号
     */
    private String            catcherVersion;

    public String getMac1() {
        return mac1;
    }

    public void setMac1(String mac1) {
        this.mac1 = mac1;
    }

    public String getMac2() {
        return mac2;
    }

    public void setMac2(String mac2) {
        this.mac2 = mac2;
    }

    public Integer getCatcherNum() {
        return catcherNum;
    }

    public void setCatcherNum(Integer catcherNum) {
        this.catcherNum = catcherNum;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getCatcherName() {
        return catcherName;
    }

    public void setCatcherName(String catcherName) {
        this.catcherName = catcherName;
    }

    public Long getPayload() {
        return payload;
    }

    public void setPayload(Long payload) {
        this.payload = payload;
    }

    public Long getWawaId() {
        return wawaId;
    }

    public void setWawaId(Long wawaId) {
        this.wawaId = wawaId;
    }

    public Integer getTotality() {
        return totality;
    }

    public void setTotality(Integer totality) {
        this.totality = totality;
    }

    public Integer getStock() {
        return stock;
    }

    public void setStock(Integer stock) {
        this.stock = stock;
    }

    /**
     * catcherVersion.
     *
     * @return the catcherVersion
     */
    public String getCatcherVersion() {
        return catcherVersion;
    }

    /**
     * catcherVersion.
     *
     * @param catcherVersion the catcherVersion to set
     */
    public void setCatcherVersion(String catcherVersion) {
        this.catcherVersion = catcherVersion;
    }

}
